# GME

The GME package was created by the Gravity Modeling Group at the United States International Trade Commission. The package has been primarily developed by Peter Herman and Saad Ahmad. Additional contributions have been made by Serge Shikher, Tamara Gurevich, Samantha Schreiber, Carlos Payan, Caroline Peters, Grace Kenneally, and Austin Drenski.

Contact us at [gravity@usitc.gov](mailto://gravity@usitc.gov?subject=[GME package])

Additional information about the development team can be located at the project website at [gravity.usitc.gov](https://gravity.usitc.gov).

## Documentation
Documentation for the package can be found at [https://usitc-gravity-group.github.io/GME/](https://usitc-gravity-group.github.io/GME/).

## Release information

GME is free, open-source software

*Version:* 1.3

